lilypondfiletools.make_time_signature_context_block
===================================================

.. autofunction:: abjad.tools.lilypondfiletools.make_time_signature_context_block.make_time_signature_context_block
